/*
 * Copyright 2012-2013 Brian Thomas Matthews
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.btmatthews.maven.plugins.ldap.unboundid;

import com.btmatthews.utils.monitor.Server;
import com.btmatthews.utils.monitor.ServerFactory;

/**
 * Factory that creates instances of {@link com.btmatthews.maven.plugins.ldap.unboundid.UnboundIDServer}.
 *
 * @author <a href="mailto:brian@btmatthews.com">Brian Matthews</a>
 * @since 1.1.1
 */
public class UnboundIDServerFactory implements ServerFactory {

    /**
     * Return the name of the servers created by this factory.
     *
     * @return Always returns {@code unboundid}.
     */
    @Override
    public String getServerName() {
        return "unboundid";
    }

    /**
     * Create new instance of {@link com.btmatthews.maven.plugins.ldap.unboundid.UnboundIDServer}.
     *
     * @return The newly create instance of {@link com.btmatthews.maven.plugins.ldap.unboundid.UnboundIDServer}.
     */
    @Override
    public Server createServer() {
        return new UnboundIDServer();
    }
}
